==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/networkanalytics/kotlin/inputs/ListDataProductRolesAssignmentsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkanalytics.kotlin.inputs

import com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property dataProductName The data product resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListDataProductRolesAssignmentsPlainArgs(
    public val dataProductName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs =
        com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs.builder()
            .dataProductName(dataProductName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDataProductRolesAssignmentsPlainArgs].
 */
@PulumiTagMarker
public class ListDataProductRolesAssignmentsPlainArgsBuilder internal constructor() {
    private var dataProductName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The data product resource name
     */
    @JvmName("gqegnhxayxtcpwme")
    public suspend fun dataProductName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataProductName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("oybxkgaehhpvbxib")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListDataProductRolesAssignmentsPlainArgs =
        ListDataProductRolesAssignmentsPlainArgs(
            dataProductName = dataProductName ?: throw PulumiNullFieldException("dataProductName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/networkanalytics/kotlin/inputs/ListDataProductRolesAssignmentsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.networkanalytics.kotlin.inputs

import com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property dataProductName The data product resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 */
public data class ListDataProductRolesAssignmentsPlainArgs(
    public val dataProductName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs =
        com.pulumi.azurenative.networkanalytics.inputs.ListDataProductRolesAssignmentsPlainArgs.builder()
            .dataProductName(dataProductName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListDataProductRolesAssignmentsPlainArgs].
 */
@PulumiTagMarker
public class ListDataProductRolesAssignmentsPlainArgsBuilder internal constructor() {
    private var dataProductName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The data product resource name
     */
    @JvmName("wkchfqhgigmgkttu")
    public suspend fun dataProductName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataProductName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("kgtoinjekteovcnb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListDataProductRolesAssignmentsPlainArgs =
        ListDataProductRolesAssignmentsPlainArgs(
            dataProductName = dataProductName ?: throw PulumiNullFieldException("dataProductName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
